@@ -12,7 +12,7 @@
  *  You may distribute this under the terms of either the GNU General Public
  *  License or the Artistic License, as specified in the Perl README file.
  *
- *  $Id: dbdimp.h 9284 2007-03-20 13:47:18Z capttofu $
+ *  $Id: dbdimp.h 10412 2007-12-11 21:42:15Z capttofu $
  */
 
 /*
@@ -21,6 +21,7 @@
 #include <DBIXS.h>  /* installed by the DBI module                        */
 #include <mysql.h>  /* Comes with MySQL-devel */
 #include <mysqld_error.h>  /* Comes MySQL */
+
 #include <errmsg.h> /* Comes with MySQL-devel */
 
 /*
@@ -29,6 +30,7 @@
  * statements as opposed to emulation in the driver
 */
 #define SQL_STATE_VERSION 40101
+#define WARNING_COUNT_VERSION 40101
 #define FIELD_CHARSETNR_VERSION 40101 /* should equivalent to 4.1.0  */
 #define MULTIPLE_RESULT_SET_VERSION 40102
 #define SERVER_PREPARE_VERSION 40103
@@ -43,6 +45,9 @@
 #endif
 
 
+#if MYSQL_VERSION_ID < WARNING_COUNT_VERSION
+#define mysql_warning_count(svsock) 0
+#endif
 
 /*
  *  The following are return codes passed in $h->err in case of
